@@ -8,10 +8,6 @@ pub mod v1_accelerator;
 pub use self::v1_accelerator::V1Accelerator;
 pub mod v1_create_sip_teleport;
 pub use self::v1_create_sip_teleport::V1CreateSipTeleport;
-pub mod v1_global_turn_response;
-pub use self::v1_global_turn_response::V1GlobalTurnResponse;
-pub mod v1_global_turn_server;
-pub use self::v1_global_turn_server::V1GlobalTurnServer;
 pub mod v1_list_accelerator_response;
 pub use self::v1_list_accelerator_response::V1ListAcceleratorResponse;
 pub mod v1_list_sip_teleport_response;
@@ -28,3 +24,7 @@ pub mod v1_transport_type;
 pub use self::v1_transport_type::V1TransportType;
 pub mod v1_update_sip_teleport;
 pub use self::v1_update_sip_teleport::V1UpdateSipTeleport;
+pub mod v1_web_rtc_cdn_response;
+pub use self::v1_web_rtc_cdn_response::V1WebRtcCdnResponse;
+pub mod v1_web_rtc_cdn_server;
+pub use self::v1_web_rtc_cdn_server::V1WebRtcCdnServer;
